@@ -48,7 +48,7 @@ set_locale_for_clients() {
     echo "LANG=${LANG}" > $ih/${grep_file}
   done
   echo "Since some config files are modified in template client, recreating template tarball for DRBL SSI..."
-  gen_ssi_files
+  drbl-gen-ssi-files
 } # end of set_locale_for_clients
 #
 config_network(){
@@ -62,7 +62,7 @@ config_network(){
     eth_ports="$(get-nic-devs)"
     configured_port_list=""
     for i in $eth_ports; do
-      if [ -n "$(get_ip $i)" ]; then
+      if [ -n "$(drbl-get-ipadd $i)" ]; then
        configured_port_list="$configured_port_list $i"
       fi
     done
